using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    public partial class StaticText : StaticScreenPiece
    {
        private bool myNoWrap, myAlignCenter, myAlignRight;

        /// <summary>
        /// Will text and images wrap to the window size
        /// </summary>        
        [XmlElement("NoWrap", IsNullable = false)]
        [Browsable(true), Description("Don't allow this text to wrap if squished")]
        public bool NoWrap { get { return myNoWrap; } set { myNoWrap = value; } }
        
        /// <summary>
        /// Will text be centered
        /// </summary>
        [XmlElement("AlignCenter", IsNullable = false)]
        [Browsable(true), Description("Center this text")]
        public bool AlignCenter { get { return myAlignCenter; } set { myAlignCenter = value; } }
        
        /// <summary>
        /// Will text be on the right side
        /// </summary>
        [XmlElement("AlignRight", IsNullable = false)]
        [Browsable(true), Description("Right justify this text")]
        public bool AlignRight { get { return myAlignRight; } set { myAlignRight = value; } }

        public StaticText() : this(null) { }
        public StaticText(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            StaticText temp_StaticText = obj as StaticText;
            if (temp_StaticText != null)
            {
                NoWrap = temp_StaticText.NoWrap;
                AlignCenter = temp_StaticText.AlignCenter;
                AlignRight = temp_StaticText.AlignRight;
            }
        }
    }
}
